Knowledge Graph Embedding Learning
=====

This is an learning modules with PyTorch to learn knowledge embeddings. It's more towards research now.
It heavily used another library [kgekit](https://github.com/fantasticfears/kgekit).

The design follows DIY, data oriented design and a few OO classes.

# Features

- Small memory footprint
- Fast parallelized sampling and batch done in C++
- Deterministic
- Easily extensible and readable
- Visualization
